==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/autoaway/translations/autoaway_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Controlla assenza ogni</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Setta lo stato su assente dopo</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Setta lo stato invisibile dopo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nuova descrizione</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Setta lo stato su autoaway esteso dopo</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n secondo</numerusform><numerusform>%n secondi</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Non cambiare</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Inattività</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Aggiorna stato ogni</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minuto</numerusform><numerusform>%n minuti</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prepend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoAway</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation>Non aggiornare</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/autoaway/translations/autoaway_it.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="it" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Status</source>
        <translation>Stato</translation>
    </message>
    <message>
        <source>Check idle every</source>
        <translation>Controlla assenza ogni</translation>
    </message>
    <message>
        <source>Set status to away after</source>
        <translation>Setta lo stato su assente dopo</translation>
    </message>
    <message>
        <source>Set status to invisible after</source>
        <translation>Setta lo stato invisibile dopo</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Descrizione</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message>
        <source>New description</source>
        <translation>Nuova descrizione</translation>
    </message>
    <message>
        <source>Set status to extended away after</source>
        <translation>Setta lo stato su autoaway esteso dopo</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n secondo</numerusform><numerusform>%n secondi</numerusform></translation>
    </message>
    <message>
        <source>Do Not Change</source>
        <translation>Non cambiare</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Inactivity</source>
        <translation>Inattività</translation>
    </message>
    <message>
        <source>Refresh status every</source>
        <translation>Aggiorna stato ogni</translation>
    </message>
    <message>
        <source>Switch to &apos;away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation><numerusform>%n minuto</numerusform><numerusform>%n minuti</numerusform></translation>
    </message>
    <message>
        <source>Switch to &apos;auto extended away&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;invisible&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to &apos;offline&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set status to offline after</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Status description when inactive</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Prepend</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoawayConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t refresh</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
